<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package rst
 */
if ( ! function_exists( 'angllia_the_posts_navigation' ) ) :
/**
 * Display navigation to next/previous set of posts when applicable.
 *
 * @todo Remove this function when WordPress 4.3 is released.
 */
function angllia_the_posts_navigation($the_query) {
	// Don't print empty markup if there's only one page.
	global $paged, $wp_query;
	if( !isset($the_query) || empty($the_query) ) $the_query = $wp_query;
	$max_paged = $the_query->max_num_pages;
	if ( $max_paged < 2 ) {
		return;
	}
	$big = 999999999;
	$my_page = max( get_query_var('paged'), get_query_var('page') );
	$paginate_links = paginate_links( array(
		'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
		'format' => '?paged=%#%',
		'current' => max( 1, $my_page ),
		'total' => $max_paged,
		'prev_text'    => '<i class="fa fa-angle-left"></i>',
		'next_text'    => '<i class="fa fa-angle-right"></i>',
		'type'			=> 'array'
	 ));
	
	if( is_array( $paginate_links ) ) {
		$paged = ( $my_page == 0 ) ? 1 : $my_page;
		echo '<div class="rst-pagination">';
		echo '<div class="wp-pagenavi">';
			foreach ( $paginate_links as $page ) {
				echo force_balance_tags($page);
			}
		echo '</div>';
		echo '</div>';
	}
}
endif;
if ( ! function_exists( 'angllia_the_posts_navigation_ajax' ) ) :
	function angllia_the_posts_navigation_ajax() {
		global $rst_pagenavi;
		if( $rst_pagenavi['max-paged'] >= 1 ) { 
	?>
	<div class="rst-pagination">
		<div class="rst-load-more text-center">
			<a href="javascript:;" data-key="<?php echo esc_attr($rst_pagenavi['key']) ?>" data-disable="0" data-max-paged="<?php echo esc_attr($rst_pagenavi['max-paged']) ?>" data-paged="2" class="rst-ajax-load-more">
				<span><?php _e( 'Load more posts', 'angllia' ); ?></span><i class="fa fa-spinner fa-spin"></i>
			</a>
		</div>
	</div>
	<?php
		}
	}
	
endif;
if ( ! function_exists( 'angllia_navigation_prev_next' ) ) :
	function angllia_navigation_prev_next($the_query) {
		global $wp_query, $paged;
		if( !isset($the_query) || empty($the_query) ) $the_query = $wp_query;
		$paged = max( get_query_var( 'paged' ), get_query_var( 'page' ));
		
		if ( $the_query->max_num_pages > 1 ) :  ?>
		<div class="rst-pagination">
		<nav class="row navigation" role="navigation">
			<div class="col-sm-6 nav-previous text-left"><?php previous_posts_link( ' <i class="fa fa-long-arrow-left" aria-hidden="true"></i> Newer Posts
' ); ?></div>
			<div class="col-sm-6 nav-next text-right"><?php next_posts_link( 'Older Posts <i class="fa fa-long-arrow-right" aria-hidden="true"></i>
', $the_query -> max_num_pages ); ?></div>
		</nav>
		</div>
		
	<?php 
		endif;
	}
	
endif;
if ( ! function_exists( 'angllia_the_post_navigation' ) ) :
/**
 * Display navigation to next/previous post when applicable.
 *
 * @todo Remove this function when WordPress 4.3 is released.
 */
function angllia_the_post_navigation() {
	// Don't print empty markup if there's nowhere to navigate.
	$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
	$next     = get_adjacent_post( false, '', false );
	if ( ! $next && ! $previous ) {
		return;
	}
	?>
	<nav class="navigation post-navigation" role="navigation">
		<div class="nav-links">
			<?php
				previous_post_link( '<div class="nav-previous">%link</div>', '%title' );
				next_post_link( '<div class="nav-next">%link</div>', '%title' );
			?>
		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}
endif;
if ( ! function_exists( 'angllia_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function angllia_posted_on() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
	}
	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);
	$posted_on = sprintf(
		_x( 'Posted on %s', 'post date', 'angllia' ),
		'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
	);
	$byline = sprintf(
		_x( 'by %s', 'post author', 'angllia' ),
		'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
	);
	echo '<span class="posted-on">' . $posted_on . '</span><span class="byline"> ' . $byline . '</span>';
}
endif;
if ( ! function_exists( 'angllia_entry_footer' ) ) :
/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function angllia_entry_footer() {
	// Hide category and tag text for pages.
	if ( 'post' == get_post_type() ) {
		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( __( ', ', 'angllia' ) );
		if ( $categories_list && rst_categorized_blog() ) {
			printf( '<span class="cat-links">' . __( 'Posted in %1$s', 'angllia' ) . '</span>', $categories_list );
		}
		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( '', __( ', ', 'angllia' ) );
		if ( $tags_list ) {
			printf( '<span class="tags-links">' . __( 'Tagged %1$s', 'angllia' ) . '</span>', $tags_list );
		}
	}
	if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
		echo '<span class="comments-link">';
		comments_popup_link( __( 'Leave a comment', 'angllia' ), __( '1 Comment', 'angllia' ), __( '% Comments', 'angllia' ) );
		echo '</span>';
	}
	edit_post_link( __( 'Edit', 'angllia' ), '<span class="edit-link">', '</span>' );
}
endif;
if ( ! function_exists( 'angllia_the_archive_title' ) ) :
/**
 * Shim for `angllia_the_archive_title()`.
 *
 * Display the archive title based on the queried object.
 *
 * @todo Remove this function when WordPress 4.3 is released.
 *
 * @param string $before Optional. Content to prepend to the title. Default empty.
 * @param string $after  Optional. Content to append to the title. Default empty.
 */
function angllia_the_archive_title( $before = '', $after = '' ) {
	if ( is_category() ) {
		$title = sprintf( __( 'Category: %s', 'angllia' ), single_cat_title( '', false ) );
	} elseif ( is_tag() ) {
		$title = sprintf( __( 'Tag: %s', 'angllia' ), single_tag_title( '', false ) );
	} elseif ( is_author() ) {
		$title = sprintf( __( 'Author: %s', 'angllia' ), '<span class="vcard">' . get_the_author() . '</span>' );
	} elseif ( is_year() ) {
		$title = sprintf( __( 'Year: %s', 'angllia' ), get_the_date( _x( 'Y', 'yearly archives date format', 'angllia' ) ) );
	} elseif ( is_month() ) {
		$title = sprintf( __( 'Month: %s', 'angllia' ), get_the_date( _x( 'F Y', 'monthly archives date format', 'angllia' ) ) );
	} elseif ( is_day() ) {
		$title = sprintf( __( 'Day: %s', 'angllia' ), get_the_date( _x( 'F j, Y', 'daily archives date format', 'angllia' ) ) );
	} elseif ( is_tax( 'post_format' ) ) {
		if ( is_tax( 'post_format', 'post-format-aside' ) ) {
			$title = _x( 'Asides', 'post format archive title', 'angllia' );
		} elseif ( is_tax( 'post_format', 'post-format-gallery' ) ) {
			$title = _x( 'Galleries', 'post format archive title', 'angllia' );
		} elseif ( is_tax( 'post_format', 'post-format-image' ) ) {
			$title = _x( 'Images', 'post format archive title', 'angllia' );
		} elseif ( is_tax( 'post_format', 'post-format-video' ) ) {
			$title = _x( 'Videos', 'post format archive title', 'angllia' );
		} elseif ( is_tax( 'post_format', 'post-format-quote' ) ) {
			$title = _x( 'Quotes', 'post format archive title', 'angllia' );
		} elseif ( is_tax( 'post_format', 'post-format-link' ) ) {
			$title = _x( 'Links', 'post format archive title', 'angllia' );
		} elseif ( is_tax( 'post_format', 'post-format-status' ) ) {
			$title = _x( 'Statuses', 'post format archive title', 'angllia' );
		} elseif ( is_tax( 'post_format', 'post-format-audio' ) ) {
			$title = _x( 'Audio', 'post format archive title', 'angllia' );
		} elseif ( is_tax( 'post_format', 'post-format-chat' ) ) {
			$title = _x( 'Chats', 'post format archive title', 'angllia' );
		}
	} elseif ( is_post_type_archive() ) {
		$title = sprintf( __( 'Archives: %s', 'angllia' ), post_type_archive_title( '', false ) );
	} elseif ( is_tax() ) {
		$tax = get_taxonomy( get_queried_object()->taxonomy );
		/* translators: 1: Taxonomy singular name, 2: Current taxonomy term */
		$title = sprintf( __( '%1$s: %2$s', 'angllia' ), $tax->labels->singular_name, single_term_title( '', false ) );
	} else {
		$title = __( 'Archives', 'angllia' );
	}
	/**
	 * Filter the archive title.
	 *
	 * @param string $title Archive title to be displayed.
	 */
	$title = apply_filters( 'get_angllia_the_archive_title', $title );
	if ( ! empty( $title ) ) {
		echo ($before . $title . $after);
	}
}
endif;
if ( ! function_exists( 'angllia_the_archive_description' ) ) :
/**
 * Shim for `angllia_the_archive_description()`.
 *
 * Display category, tag, or term description.
 *
 * @todo Remove this function when WordPress 4.3 is released.
 *
 * @param string $before Optional. Content to prepend to the description. Default empty.
 * @param string $after  Optional. Content to append to the description. Default empty.
 */
function angllia_the_archive_description( $before = '', $after = '' ) {
	$description = apply_filters( 'get_angllia_the_archive_description', term_description() );
	if ( ! empty( $description ) ) {
		/**
		 * Filter the archive description.
		 *
		 * @see term_description()
		 *
		 * @param string $description Archive description to be displayed.
		 */
		echo ($before . $description . $after);
	}
}
endif;
/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function angllia_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'rst_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			// We only need to know if there is more than one category.
			'number'     => 2,
		) );
		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );
		set_transient( 'rst_categories', $all_the_cool_cats );
	}
	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so rst_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so rst_categorized_blog should return false.
		return false;
	}
}
/**
 * Flush out the transients used in rst_categorized_blog.
 */
function angllia_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'rst_categories' );
}
add_action( 'edit_category', 'angllia_category_transient_flusher' );
add_action( 'save_post',     'angllia_category_transient_flusher' );
function angllia_tz_cp_2() { ?>
	WordPress&nbsp;Blog&nbsp;Theme&nbsp;Designed&nbsp;by&nbsp;<a href="<?php echo esc_url('https://easyblogthemes.com') ?>">EasyBlog&nbsp;Themes</a>.
<?php
}
add_action( 'angllia_cpr', 'angllia_tz_cp_2' );
function angllia_tz_cp_3() { ?>
	&nbsp;&nbsp;Powered&nbsp;by&nbsp;<a href="https://wordpress.org">WordPress</a>.
<?php
}
add_action( 'angllia_cpr', 'angllia_tz_cp_3' );